==> plugin-android-6.1.3-sources.jar: com/zoyi/channel/plugin/android/model/rest/UserChat.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.text.TextUtils;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.model.entity.Entity;
import com.zoyi.channel.plugin.android.model.entity.RecordUpdatesEntity;
import com.zoyi.channel.plugin.android.model.entity.UpdatableEntity;

/**
 * Created by mika on 2016. 12. 6..
 */
public class UserChat implements Entity, RecordUpdatesEntity, UpdatableEntity {
  private String id;
  private String channelId;
  private String personType;
  private String personId;
  private String state;
  private Long createdAt;
  private Long appUpdatedAt;
  private Long closedAt;
  private String appMessageId;
  private String hostId;
  private String hostType;
  private String review;

  @Override
  public String getId() {
    return id;
  }

  public String getChannelId() {
    return channelId;
  }

  public String getPersonType() {
    return personType;
  }

  public String getPersonId() {
    return personId;
  }

  public String getState() {
    return state;
  }

  public void setState(String state) {
    this.state = state;
  }

  public boolean isStateSolved() {
    return !TextUtils.isEmpty(state) && Const.USER_CHAT_STATE_SOLVED.equals(state);
  }

  public boolean isStateClosed() {
    return !TextUtils.isEmpty(state) && Const.USER_CHAT_STATE_CLOSED.equals(state);
  }

  public boolean isSupporting() {
    return Const.USER_CHAT_STATE_SUPPORTING.equals(state);
  }

  public boolean isStateRemoved() {
    return !TextUtils.isEmpty(state) && Const.USER_CHAT_STATE_REMOVED.equals(state);
  }

  public Long getCreatedAt() {
    return createdAt;
  }

  @Override
  public Long getUpdatedAt() {
    return appUpdatedAt;
  }

  public String getHostId() {
    return hostId;
  }

  public String getHostType() {
    return hostType;
  }

  public String getReview() {
    return review;
  }

  public Long getClosedAt() {
    return closedAt;
  }

  public final static String CLASSNAME = "UserChat";
}

==> plugin-android-6.1.4-sources.jar: com/zoyi/channel/plugin/android/model/rest/UserChat.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.text.TextUtils;
import com.zoyi.channel.plugin.android.global.Const;
import com.zoyi.channel.plugin.android.model.entity.Entity;
import com.zoyi.channel.plugin.android.model.entity.RecordUpdatesEntity;
import com.zoyi.channel.plugin.android.model.entity.UpdatableEntity;

/**
 * Created by mika on 2016. 12. 6..
 */
public class UserChat implements Entity, RecordUpdatesEntity, UpdatableEntity {
  private String id;
  private String channelId;
  private String personType;
  private String personId;
  private String state;
  private Long createdAt;
  private Long appUpdatedAt;
  private Long closedAt;
  private String appMessageId;
  private String assigneeId;
  private String assigneeType;
  private String review;

  @Override
  public String getId() {
    return id;
  }

  public String getChannelId() {
    return channelId;
  }

  public String getPersonType() {
    return personType;
  }

  public String getPersonId() {
    return personId;
  }

  public String getState() {
    return state;
  }

  public void setState(String state) {
    this.state = state;
  }

  public boolean isStateSolved() {
    return !TextUtils.isEmpty(state) && Const.USER_CHAT_STATE_SOLVED.equals(state);
  }

  public boolean isStateClosed() {
    return !TextUtils.isEmpty(state) && Const.USER_CHAT_STATE_CLOSED.equals(state);
  }

  public boolean isSupporting() {
    return Const.USER_CHAT_STATE_SUPPORTING.equals(state);
  }

  public boolean isStateRemoved() {
    return !TextUtils.isEmpty(state) && Const.USER_CHAT_STATE_REMOVED.equals(state);
  }

  public Long getCreatedAt() {
    return createdAt;
  }

  @Override
  public Long getUpdatedAt() {
    return appUpdatedAt;
  }

  public String getAssigneeId() {
    return assigneeId;
  }

  public String getAssigneeType() {
    return assigneeType;
  }

  public String getReview() {
    return review;
  }

  public Long getClosedAt() {
    return closedAt;
  }

  public final static String CLASSNAME = "UserChat";
}
